from setuptools import setup

setup(name='thebrukhellomodule',
      version='3.0',
      description='Hello!',
      packages=['thebrukhellomodule'],
      author_email='thebrukprojects@gmail.com',
      zip_safe=False)
